Module defs

Module defs 

Structs

ChannelState
Per-channel pts snapshot.
Gap
Returned by MessageBoxes::process_updates when a gap is detected.
MessageBoxes
All live message boxes. The single authority for update-gap detection.
UpdatesStateSnap
Full snapshot of the update state for session persistence.

Enums

UpdatesLike
Anything that should be treated as an update batch.

Type Aliases

UpdateAndPeers